@@ -1021,7 +1021,11 @@ terminal_widget_fork_command (GtkWidget   *widget,
   
   gdk_flush ();
   errno = 0;
-  switch ((*child_pid = zvt_term_forkpty (term, update_records)))
+  switch ((*child_pid = zvt_term_forkpty (term, update_records ?
+                                          (ZVT_TERM_DO_UTMP_LOG |
+                                           ZVT_TERM_DO_WTMP_LOG |
+                                           ZVT_TERM_DO_LASTLOG) :
+                                          0)))
     {
     case -1:
       g_set_error (err,
@@ -1101,3 +1105,24 @@ terminal_widget_supports_pango_fonts (void)
 {
   return FALSE;
 }
+
+const char*
+terminal_widget_get_encoding (GtkWidget *widget)
+{
+  const char *charset = NULL;
+  g_get_charset (&charset);
+  return charset;
+}
+
+void
+terminal_widget_set_encoding (GtkWidget  *widget,
+                              const char *encoding)
+{
+  ; /* does nothing */
+}
+
+gboolean
+terminal_widget_supports_dynamic_encoding (void)
+{
+  return FALSE;
+}
